@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: hh2.c,v 1.2 2000/04/17 13:50:53 rug Exp $
+ * $Id: hh2.c,v 1.5 2001/05/30 05:46:55 takesako Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -20,8 +20,16 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
-#include <string.h>
+#ifdef HAVE_STRING_H
+# include <string.h>
+#else
+# include <strings.h>
+#endif
 #include "kakasi.h"
 
 struct H2rom_tbl {
@@ -130,13 +138,13 @@ H2rom_h_table[] = {
     "\244\303\244\301\244\343", "ttya", "\244\303\244\301\244\345", "ttyu", "\244\303\244\301\244\347", "ttyo", "\244\303\244\302", "ddi",
     "\244\303\244\302\244\343", "ddya", "\244\303\244\302\244\345", "ddyu", "\244\303\244\302\244\347", "ddyo", "\244\303\244\304", "ttu",
     "\244\303\244\305", "ddu", "\244\303\244\306", "tte", "\244\303\244\307", "dde", "\244\303\244\310", "tto", "\244\303\244\311", "ddo",
-    "\244\303\244\317", "hha", "\244\303\244\320", "bba", "\244\303\244\321", "bba", "\244\303\244\322", "hhi",
+    "\244\303\244\317", "hha", "\244\303\244\320", "bba", "\244\303\244\321", "ppa", "\244\303\244\322", "hhi",
     "\244\303\244\322\244\343", "hhya", "\244\303\244\322\244\345", "hhyu", "\244\303\244\322\244\347", "hhyo", "\244\303\244\323", "bbi",
-    "\244\303\244\323\244\343", "bbya", "\244\303\244\323\244\345", "bbyu", "\244\303\244\323\244\347", "bbyo", "\244\303\244\324", "bbi",
-    "\244\303\244\324\244\343", "bbya", "\244\303\244\324\244\345", "bbyu", "\244\303\244\324\244\347", "bbyo", "\244\303\244\325", "hhu",
+    "\244\303\244\323\244\343", "bbya", "\244\303\244\323\244\345", "bbyu", "\244\303\244\323\244\347", "bbyo", "\244\303\244\324", "ppi",
+    "\244\303\244\324\244\343", "ppya", "\244\303\244\324\244\345", "ppyu", "\244\303\244\324\244\347", "ppyo", "\244\303\244\325", "hhu",
     "\244\303\244\325\244\241", "ffa", "\244\303\244\325\244\243", "ffi", "\244\303\244\325\244\247", "ffe", "\244\303\244\325\244\251", "ffo",
-    "\244\303\244\326", "bbu", "\244\303\244\327", "ppu", "\244\303\244\330", "hhe", "\244\303\244\331", "bbe", "\244\303\244\332", "bbe",
-    "\244\303\244\333", "hho", "\244\303\244\334", "bbo", "\244\303\244\335", "bbo", "\244\303\244\344", "yya", "\244\303\244\346", "yyu",
+    "\244\303\244\326", "bbu", "\244\303\244\327", "ppu", "\244\303\244\330", "hhe", "\244\303\244\331", "bbe", "\244\303\244\332", "ppe",
+    "\244\303\244\333", "hho", "\244\303\244\334", "bbo", "\244\303\244\335", "ppo", "\244\303\244\344", "yya", "\244\303\244\346", "yyu",
     "\244\303\244\350", "yyo", "\244\303\244\351", "rra", "\244\303\244\352", "rri", "\244\303\244\352\244\343", "rrya",
     "\244\303\244\352\244\345", "rryu", "\244\303\244\352\244\347", "rryo", "\244\303\244\353", "rru", "\244\303\244\354", "rre",
     "\244\303\244\355", "rro",
@@ -169,7 +177,8 @@ H2rom_h_table[] = {
 
 #define H2rom_buflen 11
 
-int H2rom(c, n, type)
+int
+H2rom(c, n, type)
      Character *c;
      Character *n;
      int type;
@@ -257,21 +266,24 @@ int H2rom(c, n, type)
     return (match_more == 0) ? max_match : -max_match;
 }
 
-int H2a(c, n)
+int
+H2a(c, n)
      Character *c;
      Character *n;
 {
     return H2rom(c, n, ASCII);
 }
 
-int H2j(c, n)
+int
+H2j(c, n)
      Character *c;
      Character *n;
 {
     return H2rom(c, n, JISROMAN);
 }
 
-int H2K(c, n)
+int
+H2K(c, n)
      Character *c;
      Character *n;
 {
@@ -310,7 +322,8 @@ int H2K(c, n)
     }
 }
 
-int H2k(c, n)
+int
+H2k(c, n)
      Character *c;
      Character *n;
 {
@@ -361,7 +374,8 @@ int H2k(c, n)
 
 #ifdef WAKATIGAKI
 /* As for the hiragana as well, the function which isn't necessarily needed if reading raising becomes possible. */
-int H2H(c, n)
+int
+H2H(c, n)
      Character *c;
      Character *n;
 {
