@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: k2.c,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
+ * $Id: k2.c,v 1.3 2001/01/16 07:51:47 rug Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -20,8 +20,16 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
-#include <string.h>
+#ifdef HAVE_STRING_H
+# include <string.h>
+#else
+# include <strings.h>
+#endif
 #include "kakasi.h"
 
 struct k2rom_tbl {
@@ -121,7 +129,8 @@ k2rom_h_table[] = {
 
 #define k2rom_buflen 10
 
-static int k2rom(c, n, type)
+static int
+k2rom(c, n, type)
      Character *c;
      Character *n;
      int type;
@@ -197,21 +206,24 @@ static int k2rom(c, n, type)
     return (match_more == 0) ? max_match : -max_match;
 }
 
-int k2a(c, n)
+int
+k2a(c, n)
      Character *c;
      Character *n;
 {
     return k2rom(c, n, ASCII);
 }
 
-int k2j(c, n)
+int
+k2j(c, n)
      Character *c;
      Character *n;
 {
     return k2rom(c, n, JISROMAN);
 }
 
-int k2K(c, n)
+int
+k2K(c, n)
      Character *c;
      Character *n;
 {
@@ -278,7 +290,8 @@ int k2K(c, n)
     }
 }
     
-int k2H(c, n)
+int
+k2H(c, n)
      Character *c;
      Character *n;
 {
