@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: conv-util.c,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
+ * $Id: conv-util.c,v 1.2 2001/01/16 07:51:47 rug Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -23,7 +23,8 @@
 #include <stdio.h>
 #include "conv-util.h"
 
-int isallkana(str)
+int
+isallkana(str)
      unsigned char *str;
 {
     while(*str) {
@@ -35,7 +36,8 @@ int isallkana(str)
     return 1;
 }
 
-int isallzenkaku(str)
+int
+isallzenkaku(str)
      unsigned char *str;
 {
     while(*str) {
@@ -46,7 +48,8 @@ int isallzenkaku(str)
     return 1;
 }
 
-int includekanji(str)
+int
+includekanji(str)
      unsigned char *str;
 {
     while(*str) {
