@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: conv-util.h,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
+ * $Id: conv-util.h,v 1.2 2000/12/29 18:39:11 rug Exp $
  * Copyright (C) 1994
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -20,6 +20,19 @@
  * 02111-1307, USA.
  */
 
-extern int isallkana();
-extern int isallzenkaku();
-extern int includekanji();
+#ifndef _CONV_UTIL_H
+#define _CONV_UTIL_H
+
+#ifndef PARAMS
+# if __STDC__ || defined __cplusplus
+# define PARAMS(args) args
+# else
+# define PARAMS(args) ()
+# endif
+#endif
+
+extern int isallkana PARAMS((unsigned char *str));
+extern int isallzenkaku PARAMS((unsigned char *str));
+extern int includekanji PARAMS((unsigned char *str));
+
+#endif /* _CONV_UTIL_H */
