@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: j2.c,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
+ * $Id: j2.c,v 1.2 2001/01/16 07:51:47 rug Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -22,7 +22,8 @@
 
 #include "kakasi.h"
 
-int j2a(c, n)
+int
+j2a(c, n)
      Character *c;
      Character *n;
 {
@@ -33,7 +34,8 @@ int j2a(c, n)
     return 1;
 }
 
-int j2E(c, n)
+int
+j2E(c, n)
      Character *c;
      Character *n;
 {
