@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: kanjiio.c,v 1.2 2000/03/04 06:26:50 rug Exp $
+ * $Id: kanjiio.c,v 1.6 2001/01/16 07:51:47 rug Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -32,14 +32,19 @@
 #endif
 
 #include <stdio.h>
-#include <string.h>
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
+#ifdef HAVE_STRING_H
+# include <string.h>
 #else
-#include <stdlib.h>
+# include <strings.h>
+#endif
+#ifdef HAVE_MALLOC_H
+# include <malloc.h>
 #endif
 #include <stdlib.h>
 #include "kakasi.h"
+#ifdef LIBRARY
+# include "libkakasi.h"
+#endif
 
 #if ! defined HAVE_MEMMOVE && ! defined memmove
 # define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -66,7 +71,8 @@ unsigned char *getcharbuffer;
 static Character kanji_buf={OTHER, 0, 0};
 static int kanji_buf_set = 0;
 
-void ungetkanji(c)
+void
+ungetkanji(c)
      Character *c;
 {
     kanji_buf.type = c->type;
@@ -100,18 +106,25 @@ pbuf pcbuf = {
     NULL, -1, NULL
 };
 
-void setcharbuffer(s)
+pbuf *pcbuf_tail = &pcbuf;
+
+void
+setcharbuffer(s)
      unsigned char *s;
 {
     getcharbuffer = s;
 }
 
-void putcharpbuf(c)
+void
+putcharpbuf(c)
      int c;
 {
-    pbuf *pb = &pcbuf;
-    while (pb->size == PBSTRSIZE)
+    pbuf *pb = pcbuf_tail;
+
+    if (pb->size == PBSTRSIZE) {
 	pb = pb->next;
+	pcbuf_tail = pb;
+    }
     if (pb->size < 0) {
 	pbuf *npb;
 	if ((pb->str = (char *) malloc(PBSTRSIZE)) == NULL) {
@@ -132,7 +145,8 @@ void putcharpbuf(c)
     pb->size ++;
 }
 
-char *getpbstr() {
+char *
+getpbstr() {
     char *ret, *tmp;
     long tsize = 0;
     pbuf *pb = &pcbuf;
@@ -170,11 +184,13 @@ char *getpbstr() {
     pcbuf.str = NULL;
     pcbuf.size = -1;
     pcbuf.next = NULL;
+    pcbuf_tail = &pcbuf;
     return ret;
 }
 #endif /* LIBRARY */
 
-static int get1byte()
+static int
+get1byte()
 {
     if (input_stack_depth == 0)
 #ifdef LIBRARY
@@ -189,13 +205,15 @@ static int get1byte()
 	return input_stack[-- input_stack_depth];
 }
 
-static void unget1byte(c)
+static void
+unget1byte(c)
      int c;
 {
     input_stack[input_stack_depth ++] = c;
 }
 
-static int getc0set1(gn)
+static int
+getc0set1(gn)
      int gn;
 {
     int c3;
@@ -217,7 +235,8 @@ static int getc0set1(gn)
     return 0;
 }
 
-static void set_terms(type, term_type, GL, GR, G)
+static void
+set_terms(type, term_type, GL, GR, G)
      int type;
      int *term_type;
      int *GL;
@@ -250,19 +269,22 @@ static void set_terms(type, term_type, GL, GR, G)
     }
 }
 
-void set_input_term(type)
+void
+set_input_term(type)
      int type;
 {
     set_terms(type, &input_term_type, &input_GL, &input_GR, input_G);
 }
 
-void set_output_term(type)
+void
+set_output_term(type)
      int type;
 {
     set_terms(type, &output_term_type, &output_GL, &output_GR, output_G);
 }
 
-static int getc0set2(gn)
+static int
+getc0set2(gn)
      int gn;
 {
     int c4;
@@ -290,7 +312,8 @@ static int getc0set2(gn)
     return 0;
 }
 
-static void getc0(c, c1)
+static void
+getc0(c, c1)
      Character *c;
      int c1;
 {
@@ -418,7 +441,8 @@ static void getc0(c, c1)
     getkanji(c);
 }
 
-static void getc1(c, c1)
+static void
+getc1(c, c1)
      Character *c;
      int c1;
 {
@@ -448,7 +472,8 @@ static void getc1(c, c1)
     }
 }
 
-void getkanji(c)
+void
+getkanji(c)
      Character *c;
 {
     int c1;
@@ -549,7 +574,8 @@ void getkanji(c)
     }
 }
 
-static void separator_proc(c)
+static void
+separator_proc(c)
      Character *c;
 {
     Character sep;
@@ -580,7 +606,8 @@ static void separator_proc(c)
 
 /* One character output */
 
-void putkanji(c)
+void
+putkanji(c)
      Character *c;
 {
     if (bunkatu_mode) {
@@ -854,7 +881,8 @@ void putkanji(c)
     }
 }
 
-int term_type_str(str)
+int
+term_type_str(str)
      char *str;
 {
     if ((strncmp(str, "oldjis", 6) == 0) ||
