@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: mkkanwa.c,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
+ * $Id: mkkanwa.c,v 1.4 2001/01/16 07:51:47 rug Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -20,19 +20,30 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
+#ifdef HAVE_STRING_H
+# include <string.h>
+#else
+# include <strings.h>
+#endif
+#include <stdlib.h>
 #include "getopt.h"
 #include "kakasi.h"
-#include "jj2.h"
 
-static void usage(argv)
+static void
+usage(argv)
      char **argv;
 {
     (void)fprintf(stderr, "usage: %s kanwadict dict1 [dict2,,,]\n", argv[0]);
     exit (2);
 }
 
-static void make_kanwa_dict(kdict)
+static void
+make_kanwa_dict(kdict)
      FILE *kdict;
 {
     unsigned char length;
@@ -63,7 +74,8 @@ static void make_kanwa_dict(kdict)
     fwrite((char *)kanwa, sizeof kanwa, 1, kdict);
 }
 
-int main(argc, argv)
+int
+main(argc, argv)
      int argc;
      char **argv;
 {
