@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: rdic-conv.c,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
+ * $Id: rdic-conv.c,v 1.2 2001/01/16 07:51:47 rug Exp $
  * Copyright (C) 1992 1994
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -23,7 +23,8 @@
 #include <stdio.h>
 #include "conv-util.h"
 
-static void jis2ujis(buffer)
+static void
+jis2ujis(buffer)
      unsigned char *buffer;
 {
     unsigned char *p, *q;
@@ -56,7 +57,8 @@ static void jis2ujis(buffer)
     *q = '\0';
 }
 
-static void extract(file_name)
+static void
+extract(file_name)
      char *file_name;
 {
     FILE *fp;
@@ -79,7 +81,8 @@ static void extract(file_name)
     }
 }
 
-int main(argc, argv)
+int
+main(argc, argv)
      int argc;
      char **argv;
 {
