@@ -1,6 +1,6 @@
 /*
  * wx2-conv.c  --  WX2 -> KAKASI dictionary converter
- * $Id: wx2-conv.c,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
+ * $Id: wx2-conv.c,v 1.3 2001/01/16 07:51:47 rug Exp $
  * Copyright(c) 1996, Hajime BABA,
  *          Department of Astronomy, Kyoto University,
  *          KYOTO, Japan, 606-01.
@@ -28,11 +28,20 @@
  *  <YOMI><tab>"<KANJI>":<HINSHI><FYKUKAI>
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
-#include <string.h>
+#ifdef HAVE_STRING_H
+# include <string.h>
+#else
+# include <strings.h>
+#endif
 #include "conv-util.h"
 
-static void sjis2ujis(sjis, ujis)
+static void
+sjis2ujis(sjis, ujis)
      unsigned char *sjis;
      unsigned char *ujis;
 {
@@ -108,7 +117,8 @@ static void sjis2ujis(sjis, ujis)
     *q = '\0';
 }
 
-static void getkanji(kanji, s)
+static void
+getkanji(kanji, s)
      char *kanji;
      char *s;
 {
@@ -124,7 +134,8 @@ static void getkanji(kanji, s)
     }
 }
 
-static void extract(file_name)
+static void
+extract(file_name)
      char *file_name;
 {
     FILE *fp;
@@ -149,7 +160,8 @@ static void extract(file_name)
     }
 }
 
-int main(argc, argv)
+int
+main(argc, argv)
      int argc;
      char **argv;
 {
